==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-sv_SE-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sv_SE\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Affärs kontakt data"

, "Organisation / Unit"
: "Orginasition / Enhet"

, "Business Address"
: "Affärs adresser"

, "Email"
: "E-post"

, "Telephone Work"
: "Telefon Arbete"

, "Telephone Cellphone"
: "Telefon Mobiltelefon"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Sida"

, "URL"
: "URL"

, "Role"
: "Roll"

, "Room"
: "Rum"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Privat Kontakt Data"

, "Private Address"
: "Privat Adress"

, "Email Home"
: "E-post hem"

, "Telephone Home"
: "Telefon Hem"

, "Telephone Cellphone Private"
: "Telefon Mobiltelefon Privat"

, "Telephone Fax Home"
: "Telefon Fax Hem"

, "URL Home"
: "URL hem"

, "Other Data"
: "Andra Data"

, "Birthday"
: "Födelsedag"

, "Job Title"
: "Arbets namn"

, "Dear Mister"
: ""

, "Dear Miss"
: ""

, "Dear"
: ""

, "Mister"
: ""

, "Misses"
: ""

, "%s's personal addressbook"
: "%s personliga adressbok"

, "Lists"
: "Listor"

, "List Roles"
: ""

, "manage shared addressbooks"
: "hantera delade adressböcker"

, "Create new shared addressbook folders"
: "Skapa nya delade adressböcker-mappar"

, "manage shared addressbook favorites"
: "hantera delade adressboks favoriter"

, "Create or update shared addressbook favorites"
: "Skapa eller uppdatera delade adressboks favoriter"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: "CardDAV URL"

, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "List Role, , n); gettext("
: [
  ""
 ,""

]
, "Members"
: ""

, "Remove Member"
: ""

, "Map"
: "Karta"

, "Personal Information"
: "Personlig Information"

, "Salutation"
: "Hälsning"

, "Title"
: "Titel"

, "First Name"
: "Första Namn"

, "Middle Name"
: "Mellan Namn"

, "Last Name"
: "Efternamn"

, "Company"
: "Företag"

, "Unit"
: "Enhet"

, "Suffix"
: "Ändelse"

, "Job Role"
: "Arbetar Roll"

, "Display Name"
: "Visnings Namn"

, "Contact Information"
: "Kontakt Information"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (Privat)"

, "Mobile (private)"
: "Mobil (Privat)"

, "Fax (private)"
: "Fax (Privat)"

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (Privat)"

, "Web"
: "Webb"

, "Company Address"
: "Företags Adress"

, "Street"
: "Gata"

, "Street 2"
: "Gata 2"

, "Region"
: "Region"

, "Postal Code"
: "Postkod"

, "City"
: "Stad"

, "Country"
: "Land"

, "Description"
: "Beskrivning"

, "Enter description"
: "Skriv beskrivning"

, "Export as pdf"
: "Exportera som pdf "

, "Parse address"
: "Analysera adress"

, "Paste address"
: "Analysera adress"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Avsluta tecken läge"

, "New Contact"
: "Ny Kontakt"

, "Addressbook, Addressbooks"
: [
  "Adressbok"
 ,"Adressböcker"

]
, "ID"
: ""

, "Name"
: "Namn"

, "Member of List"
: "Medlem av Lista"

, "Street (Company Address)"
: "Gata (Företags Adress)"

, "Street 2 (Company Address)"
: "Gata 2 (Företags Adress)"

, "City (Company Address)"
: "Stad (Företags Adress)"

, "Region (Company Address)"
: "Region (Företags Adress)"

, "Postal Code (Company Address)"
: "Postkod (Företags Adress)"

, "Country (Company Address)"
: "Land (Företags Adress)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gata (Privat Adress)"

, "Street 2 (Private Address)"
: "Gata 2 (Privat Adress)"

, "City (Private Address)"
: "Stad (Privat Adress)"

, "Region (Private Address)"
: "Region (Privat Adress)"

, "Postal Code (Private Address)"
: "Postkod (Privat Adress)"

, "Country (Private Address)"
: "Land (Privat Adress)"

, "Company Communication"
: "Företags Kommunikation"

, "Private Communication"
: "Privat Kommunikation"

, "Web (private)"
: "Webb (privat)"

, "Contacts"
: "Kontakter"

, "Addressbooks"
: "Adressböcker"

, "User Account"
: "Användar konto"

, "Quick Search"
: ""

, "Type"
: "Typ"

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapad Tid"

, "Created By"
: "Skapad av"

, "List, Lists"
: [
  "Lista"
 ,"Listor"

]
, "Quick search"
: ""

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: "Företags adress"

, "Private address"
: "Privat adress"

, "Select contact"
: "Välj kontakt"

, "Private"
: "Privat"

, "Info"
: "Info"

, "Insecure link"
: "Osäker länk"

, "Please review this link in edit dialog."
: "Förhandsgranska denna länken i dialogrutan redigera."

, "Export {0}, Export {0}"
: [
  "Export {0}"
 ,"Export {0}"

]
, "Export as PDF"
: "Exportera som PDF"

, "Export as CSV"
: "Exportera som CSV"

, "Export as ODS"
: "Exportera som ODS"

, "Export as XLS"
: "Exportera som XLS"

, "Export as DOC"
: ""

, "Export as ..."
: "Exportera som ..."

, "Import contacts"
: "Importera kontakter"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Tags"
: "Taggar"

, "Full Name"
: "Helt Namn"

, "Postalcode"
: "Postkod"

, "Street (private)"
: "Gata (Privat)"

, "City (private)"
: "Stad (Privat)"

, "Region (private)"
: "Region (Privat)"

, "Postalcode (private)"
: "Postkod (Privat)"

, "Country (private)"
: "Land (Privat)"

, "Car phone"
: "Bil telefon"

, "Pager"
: "Personsökare"

, "Email (private)"
: "E-post (privat)"

, "URL (private)"
: "URL (privat)"

, "Note"
: "Notifiering"

, "Timezone"
: "Tidszon"

, "Geo"
: "Geografisk"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: "Laddade upp ny kontaktbild."

, "All contacts"
: "Alla kontakter"

, "Default Addressbook"
: "Standard Adressbok"

, "The default addressbook for new contacts"
: "Standard adressboken för nya kontakter"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on addressbook startup"
: "Standardinställningen favoriten som laddas vid addressbook start"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "All Contacts"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: "Kontakta duplicerade check områden"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Dessa fält kontrolleras när en ny kontakt skapas. Om en post med samma data inom de områden hittas, en dubblett undantag skapas."

, "Contact salutations available"
: "Kontakt hälsningsfraser tillgängliga"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Möjliga kontakt hälsningar. Observera att ytterligare värden kan påverka andra adressböcker på export eller synkronisering."

, "Mr"
: "Mr"

, "Ms"
: "Ms"

, "Parsing rules for addresses"
: "Parsing regler för adresser"

, "Path to a XML file with address parsing rules."
: "Väg till en XML-fil med adress parsing regler."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Tyska"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kontakter importerade på  ###CURRENTDATE### vid ###CURRENTTIME### av ###USERFULLNAME###"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Kontakt CSV import från Outlook adress bok"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importera kontakter från Google adressbok"

, "Contact CSV import from mac address book"
: "Kontakt CSV import"

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Kontakt VCARD import"

, "Internal Contacts"
: "Interna Kontakter"

, "All contacts I have read grants for"
: "Alla kontakter Jag har Läsrättigheter för"

, "My company"
: "Mitt företag"

, "All coworkers in my company"
: "Alla medarbetare i mitt företag"

, "My contacts"
: "Mina kontakter"

, "All contacts in my Addressbooks"
: "Alla kontakter i mina Adressböcker"

, "Last modified by me"
: "Senast ändrad av mig"

, "All contacts that I have last modified"
: "Alla kontakter som Jag senast har ändrat"

, "Contact"
: "Kontakt"

, "List Role"
: ""

, "Addressbook"
: "Adressbok"

, "List"
: "Lista"

, "Email Address"
: ""

, "Export {0}"
: "Export {0}"

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:12+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sv_SE\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Affärs kontakt data"

, "Organisation / Unit"
: "Orginasition / Enhet"

, "Business Address"
: "Affärs adresser"

, "Email"
: "E-post"

, "Telephone Work"
: "Telefon Arbete"

, "Telephone Cellphone"
: "Telefon Mobiltelefon"

, "Telephone Car"
: "Telefon Bil"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Telefon Sida"

, "URL"
: "URL"

, "Role"
: "Roll"

, "Room"
: "Rum"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Assistent Telefon"

, "Private Contact Data"
: "Privat Kontakt Data"

, "Private Address"
: "Privat Adress"

, "Email Home"
: "E-post hem"

, "Telephone Home"
: "Telefon Hem"

, "Telephone Cellphone Private"
: "Telefon Mobiltelefon Privat"

, "Telephone Fax Home"
: "Telefon Fax Hem"

, "URL Home"
: "URL hem"

, "Other Data"
: "Andra Data"

, "Birthday"
: "Födelsedag"

, "Job Title"
: "Arbets namn"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Listor"

]
, "Percent"
: ""

, "Description"
: "Beskrivning"

, "Members"
: "Medlemmar"

, "Type"
: "Typ"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Adressbok"
 ,"Adressböcker"

]
, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakter"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Land"

, "City"
: "Stad"

, "Postalcode"
: "Postkod"

, "Region"
: "Region"

, "Street"
: "Gata"

, "Street 2"
: "Gata 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Land (Privat)"

, "City (private)"
: "Stad (Privat)"

, "Postalcode (private)"
: "Postkod (Privat)"

, "Region (private)"
: "Region (Privat)"

, "Street (private)"
: "Gata (Privat)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "E-post (privat)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geografisk"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Notifiering"

, "Last Name"
: "Efternamn"

, "Display Name"
: "Visnings Namn"

, "Full Name"
: "Helt Namn"

, "First Name"
: "Första Namn"

, "Middle Name"
: "Mellan Namn"

, "Title"
: "Titel"

, "Suffix"
: "Ändelse"

, "Company"
: "Företag"

, "Unit"
: "Enhet"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Arbetar Roll"

, "Salutation"
: "Hälsning"

, "syncBackendIds"
: ""

, "Car phone"
: "Bil telefon"

, "Mobile"
: "Mobil"

, "Mobile (private)"
: "Mobil (Privat)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (Privat)"

, "Phone (private)"
: "Telefon (Privat)"

, "Pager"
: "Personsökare"

, "Phone"
: "Telefon"

, "Timezone"
: "Tidszon"

, "Web"
: "Webb"

, "URL (private)"
: "URL (privat)"

, "Label"
: ""

, "Lists"
: "Listor"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Kontakt Information"

, "Company Address"
: "Företags Adress"

, "New Contact"
: "Ny Kontakt"

, "ID"
: ""

, "Name"
: "Namn"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importera kontakter"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privat"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Taggar"

, "List Roles"
: ""

, "Street (Company Address)"
: "Gata (Företags Adress)"

, "Street 2 (Company Address)"
: "Gata 2 (Företags Adress)"

, "City (Company Address)"
: "Stad (Företags Adress)"

, "Region (Company Address)"
: "Region (Företags Adress)"

, "Postal Code (Company Address)"
: "Postkod (Företags Adress)"

, "Country (Company Address)"
: "Land (Företags Adress)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Gata (Privat Adress)"

, "Street 2 (Private Address)"
: "Gata 2 (Privat Adress)"

, "City (Private Address)"
: "Stad (Privat Adress)"

, "Region (Private Address)"
: "Region (Privat Adress)"

, "Postal Code (Private Address)"
: "Postkod (Privat Adress)"

, "Country (Private Address)"
: "Land (Privat Adress)"

, "Company Communication"
: "Företags Kommunikation"

, "Private Communication"
: "Privat Kommunikation"

, "E-Mail"
: "E-Post"

, "E-Mail (private)"
: "E-Post (Privat)"

, "Web (private)"
: "Webb (privat)"

, "Contacts"
: "Kontakter"

, "Addressbooks"
: "Adressböcker"

, "User Account"
: "Användar konto"

, "Quick Search"
: ""

, "Postal Code"
: "Postkod"

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapad Tid"

, "Created By"
: "Skapad av"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Skriv beskrivning"

, "{0} must be given"
: ""

, "Member of List"
: "Medlem av Lista"

, "Map"
: "Karta"

, "Company address"
: "Företags adress"

, "Private address"
: "Privat adress"

, "CardDAV URL"
: "CardDAV URL"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Personlig Information"

, "Parse address"
: "Analysera adress"

, "Print contact"
: "Skriv ut kontakt"

, "Paste address"
: "Analysera adress"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Infoga en adress eller URI till ett vCard som ska importeras: "

, "Failed to parse address!"
: "Import av adress misslyckades!"

, "The address could not be read."
: "Adressen kunde inte läsas."

, "End token mode"
: "Avsluta tecken läge"

, "Remove Member"
: "Ta bort medlem"

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: "Sök efter användare ..."

, "Search for Contacts ..."
: "Sök efter kontakter ..."

, "All contacts"
: "Alla kontakter"

, "Default Addressbook"
: "Standard Adressbok"

, "The default addressbook for new contacts"
: "Standard adressboken för nya kontakter"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on addressbook startup"
: "Standardinställningen favoriten som laddas vid addressbook start"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Kontakta duplicerade check områden"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Dessa fält kontrolleras när en ny kontakt skapas. Om en post med samma data inom de områden hittas, en dubblett undantag skapas."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Kontakt hälsningsfraser tillgängliga"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Möjliga kontakt hälsningar. Observera att ytterligare värden kan påverka andra adressböcker på export eller synkronisering."

, "Mr"
: "Mr"

, "Ms"
: "Ms"

, "Parsing rules for addresses"
: "Parsing regler för adresser"

, "Path to a XML file with address parsing rules."
: "Väg till en XML-fil med adress parsing regler."

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Kontakt VCARD import"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kontakter importerade på  ###CURRENTDATE### vid ###CURRENTTIME### av ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Tyska"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Kontakt CSV import från Outlook adress bok"

, "Contact CSV import from mac address book"
: "Kontakt CSV import"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importera kontakter från Google adressbok"

, "manage shared addressbooks"
: "hantera delade adressböcker"

, "Create new shared addressbook folders"
: "Skapa nya delade adressböcker-mappar"

, "manage shared addressbook favorites"
: "hantera delade adressboks favoriter"

, "Create or update shared addressbook favorites"
: "Skapa eller uppdatera delade adressboks favoriter"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s personliga adressbok"

, "All contacts I have read grants for"
: "Alla kontakter Jag har Läsrättigheter för"

, "My company"
: "Mitt företag"

, "All coworkers in my company"
: "Alla medarbetare i mitt företag"

, "My contacts"
: "Mina kontakter"

, "All contacts in my Addressbooks"
: "Alla kontakter i mina Adressböcker"

, "Last modified by me"
: "Senast ändrad av mig"

, "All contacts that I have last modified"
: "Alla kontakter som Jag senast har ändrat"

, "Internal Contacts"
: "Interna Kontakter"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Swedish\nX-Poedit-Country: SWEDEN\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""
 ,""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""
 ,""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: "Lista"

, "Addressbook"
: "Adressbok"

, "Contact"
: "Kontakt"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
